import { SystemAttributes } from "./constants";
export class ElementAttributes {
    get value() {
        return this.pageElement.schema.attributes || [];
    }
    get isNodeWithAttributes() {
        return this.pageElement.nativeElement.nodeType !== Node.TEXT_NODE;
    }
    get hostElement() {
        return this.pageElement.hostElement;
    }
    constructor(pageElement) {
        this.pageElement = pageElement;
        this.attributesMap = new Map();
    }
    add(...attributes) {
        this.setAttributes(attributes);
        this.updateSchemaAttributes();
        this.pageElement.emit('view:change');
    }
    remove(...names) {
        this.removeAttributes(names);
        this.updateSchemaAttributes();
        this.pageElement.emit('view:change');
    }
    /**
     * @NotImplemented
     * @param name
     * @param force
     */
    toggle(name, force) {
        if (this.isNodeWithAttributes) {
            this.toggleAttribute(name, force);
        }
        this.pageElement.emit('view:change');
    }
    replace(name, attribute) {
        this.removeAttributes([name]);
        this.setAttributes([attribute]);
        this.updateSchemaAttributes();
        this.pageElement.emit('view:change');
    }
    init() {
        this.setAttributes(this.pageElement.schema.attributes);
    }
    updateSchemaAttributes() {
        this.pageElement.schema.attributes = Array.from(this.attributesMap).map(([name, value]) => ({ name, value }));
    }
    setAttributes(attrs) {
        attrs.forEach(attr => {
            if (this.isNodeWithAttributes) {
                this.hostElement.setAttribute(attr.name, attr.value);
            }
            if (Object.values(SystemAttributes).indexOf(attr.name) < 0) {
                this.attributesMap.set(attr.name, attr.value);
            }
        });
    }
    removeAttributes(names) {
        names.forEach(name => {
            if (this.isNodeWithAttributes) {
                this.hostElement.removeAttribute(name);
            }
            this.attributesMap.delete(name);
        });
    }
    toggleAttribute(name, force) {
        this.hostElement.toggleAttribute(name, force);
    }
}
//# sourceMappingURL=element-attributes.js.map