export class ElementClassList {
    get value() {
        return this.hostElement.classList.value ?? '';
    }
    get hostElement() {
        return this.pageElement.hostElement;
    }
    constructor(pageElement) {
        this.pageElement = pageElement;
    }
    getClassNames() {
        return this.value.split(' ')
            .filter(className => {
            const includeSystemClasses = className.includes(this.pageElement.key);
            if (includeSystemClasses) {
                return false;
            }
            const isIgnored = this.pageElement.page.getOptions().ignoreCssClasses?.includes(className);
            return !isIgnored;
        });
    }
    init() {
        this.hostElement.classList.add(...(this.pageElement.schema.cssClasses || []));
    }
    add(...classNames) {
        this.hostElement.classList.add(...classNames);
        this.updateSchemaClassList();
        this.pageElement.emit('view:change');
    }
    remove(...classNames) {
        this.hostElement.classList.remove(...classNames);
        this.updateSchemaClassList();
        this.pageElement.emit('view:change');
    }
    toggle(className, force) {
        this.hostElement.classList.toggle(className, force);
        this.updateSchemaClassList();
        this.pageElement.emit('view:change');
    }
    updateSchemaClassList() {
        this.pageElement.schema.cssClasses = this.getClassNames();
    }
}
//# sourceMappingURL=element-classlist.js.map