export class EventEmitter {
    constructor() {
        this.listenersMap = new Map();
    }
    on(eventNames, handler, options) {
        const eventNameList = eventNames.split(' ');
        eventNameList.forEach(eventName => {
            const listeners = this.getEventListeners(eventName);
            listeners.push({ handler, autoUnlistenWhen: options?.autoUnlistenWhen });
            this.listenersMap.set(eventName, listeners);
        });
        return () => this.unlisten(eventNames, handler);
    }
    once(eventName, handler) {
        const listeners = this.getEventListeners(eventName);
        listeners.push({ handler, once: true });
        return () => this.unlisten(eventName, handler);
    }
    emit(eventName, payload) {
        const listeners = this.getEventListeners(eventName);
        listeners.forEach(listener => listener.handler(payload));
        this.listenersMap.set(eventName, listeners.filter(listener => !listener.once || (listener.autoUnlistenWhen && listener.autoUnlistenWhen())));
    }
    getEventListeners(eventName) {
        return this.listenersMap.get(eventName) ?? [];
    }
    unlisten(eventNames, handler) {
        const eventNameList = eventNames.split(' ');
        eventNameList.forEach(eventName => {
            this.listenersMap.set(eventName, this.getEventListeners(eventName).filter(l => l.handler !== handler));
        });
    }
}
//# sourceMappingURL=event-emitter.js.map