import { NodeType } from "../models/page-node.model";
import { PageBaseNode } from "./page-base-node";
import { parseHTMLFragment } from "../utils";
import { nodeFactory } from "./node-factory";
import { SystemAttributes } from "../constants";
import { ElementClassList } from "../element-classlist";
import { ElementAttributes } from "../element-attributes";
import { ElementStyles } from "../element-styles";
export class PageElementNode extends PageBaseNode {
    get childElements() {
        return this.children.filter(ch => ch instanceof PageElementNode);
    }
    constructor(schema, page, parentElement) {
        super();
        this.nodeType = NodeType.element;
        this.children = [];
        this.page = page;
        this.parentElement = parentElement;
        this.schema = schema;
        this.classList = new ElementClassList(this);
        this.styles = new ElementStyles(this);
        this.attributes = new ElementAttributes(this);
        this.createElementNode();
    }
    createElementNode() {
        super.createNode();
        const elRef = this.page.documentRef.createElement(this.schema.tag);
        this.nativeElement = elRef;
        this.hostElement = this.nativeElement;
        this.parentElement?.nativeElement?.appendChild(this.nativeElement);
        if (this.schema.children?.length) {
            this.children = this.schema.children.map(childSchema => this.insertChild(childSchema, false));
        }
        this.attributes.add({ name: SystemAttributes.nodeKey, value: this.key });
        this.nativeElement.setAttribute(SystemAttributes.nodeKey, this.key);
        this.classList.init();
        this.styles.init();
        this.attributes.init();
        this.nativeElement.tabIndex = 1;
        this.page.nodeCreated(this);
    }
    getSchema() {
        this.schema.children = this.children?.map(ch => ch.getSchema());
        return this.schema;
    }
    findElement(predicate) {
        const thisSuits = super.findElement(predicate);
        if (thisSuits) {
            return this;
        }
        const found = this.children?.map(ch => ch.findElement(predicate)).filter(Boolean)[0];
        if (found) {
            return found;
        }
        return undefined;
    }
    destroy() {
        super.destroy();
        this.page.emit('node:destroy', this);
        this.emit('destroy');
    }
    insertChild(schema, emitSchemaChanged = true) {
        const node = nodeFactory(schema, this.page, this);
        this.children = [...(this.children || []), node];
        this.schema.children = [...(this.schema.children || []), node.schema];
        if (emitSchemaChanged) {
            this.page.schemaChanged();
        }
        return node;
    }
    insertHTMLFragment(fragment) {
        const schemas = parseHTMLFragment(fragment);
        const children = schemas.map(schema => this.insertChild(schema, false));
        this.page.schemaChanged();
        return children;
    }
}
//# sourceMappingURL=page-element-node.js.map