import { NodeType } from "../models/page-node.model";
import { PageBaseNode } from "./page-base-node";
import { ElementAttributes } from "../element-attributes";
export class PageTextNode extends PageBaseNode {
    get hostElement() {
        return this.wrapper || this.nativeElement;
    }
    constructor(schema, page, parentElement) {
        super();
        this.parentElement = parentElement;
        this.nodeType = NodeType.text;
        this.page = page;
        this.schema = schema;
        this.attributes = new ElementAttributes(this);
        this.createTextNode();
    }
    wrap(wrapperTag) {
        this.parentElement?.nativeElement.removeChild(this.nativeElement);
        this.wrapper = this.page.documentRef.createElement(wrapperTag);
        this.wrapper.setAttribute('data-key', this.key);
        this.wrapper.appendChild(this.nativeElement);
        this.parentElement?.nativeElement.appendChild(this.hostElement);
        this.wrapper.tabIndex = 1;
        return this.wrapper;
    }
    getValue() {
        return this.schema.attributes?.find(attr => attr.name === 'text')?.value ?? '';
    }
    createTextNode() {
        super.createNode();
        this.nativeElement = this.page.documentRef.createTextNode(this.getValue());
        this.parentElement?.nativeElement.appendChild(this.nativeElement);
        this.listenSelfEvents();
        this.page.nodeCreated(this);
    }
    listenSelfEvents() {
        this.on('view:change', () => this.onViewChange());
    }
    onViewChange() {
        const value = this.getValue();
        if (value !== this.nativeElement.textContent) {
            this.nativeElement.textContent = value;
        }
    }
}
//# sourceMappingURL=page-text-node.js.map