import { StyleType } from "../models/style.model";
import { isCssPropValueValid } from "../utils";
import { StyleBase } from './style-base';
export class BackgroundBlurStyle extends StyleBase {
    constructor(element) {
        super();
        this.element = element;
        this.styleType = StyleType.backgroundBlur;
        this.selector = `${this.styleType}-${this.element.key}`;
        this.styleSheet = this.element.page.getStyleSheet();
    }
    set(blur, apply = true) {
        this.rule.setProp('backdrop-filter', `blur(${blur})`);
        this.tryToApplyStyleRule(apply);
    }
    get() {
        return this.getEffectValue();
    }
    delete(apply = true) {
        this.rule.deleteProp('backdrop-filter');
        this.tryToApplyStyleRule(apply);
    }
    isValidValue(value) {
        return isCssPropValueValid('backdrop-filter', `blur(${value})`);
    }
    getEffectValue() {
        if (!this.rule.getProp('backdrop-filter')) {
            return '';
        }
        const match = this.rule.getProp('backdrop-filter').match(/\(([^)]+)\)/);
        return match[1];
    }
}
//# sourceMappingURL=background-blur.style.js.map