import { StyleType } from "../models/style.model";
import { StyleBase } from "./style-base";
import { camelToKebabCase } from "../utils";
export class BorderStyle extends StyleBase {
    constructor(element) {
        super();
        this.element = element;
        this.styleType = StyleType.border;
        this.selector = `${this.styleType}-${this.element.key}`;
        this.styleSheet = this.element.page.getStyleSheet();
    }
    setWidth(width, apply = true) {
        this.setInitialValuesOnChange('width');
        if (typeof width !== 'string') {
            this.rule.setProp('border-width', '0px');
            this.rule.setPropEdges('border-width', width, {
                getEdgePropKey: (edgeKey) => `border-${edgeKey}-width`
            });
        }
        else {
            this.rule.setProp('border-width', width);
            this.rule.deletePropEdges('border-width', {
                getEdgePropKey: (edgeKey) => `border-${edgeKey}-width`
            });
        }
        this.tryToApplyStyleRule(apply);
    }
    getWidth() {
        return this.rule.getPropEdges('border-width', {
            getEdgePropKey: (edgeKey) => `border-${edgeKey}-width`
        }) ?? this.rule.getProp('border-width');
    }
    setStyleType(styleType, apply = true) {
        this.setInitialValuesOnChange('styleType');
        this.rule.setPropOrPropEdges('border-style', styleType, {
            getEdgePropKey: (edgeKey) => `border-${edgeKey}-style`
        });
        this.tryToApplyStyleRule(apply);
    }
    getStyleType() {
        return this.rule.getPropOrPropEdges('border-style');
    }
    setColor(color, apply = true) {
        this.setInitialValuesOnChange('color');
        this.rule.setPropOrPropEdges('border-color', color, {
            getEdgePropKey: (edgeKey) => `border-${edgeKey}-color`
        });
        this.tryToApplyStyleRule(apply);
    }
    getColor() {
        return this.rule.getPropOrPropEdges('border-color', {
            getEdgePropKey: (edgeKey) => `border-${edgeKey}-color`,
        });
    }
    setBorderRadius(radius, apply = true) {
        this.setInitialValuesOnChange('border-radius');
        this.rule.setPropOrPropEdges('border-radius', radius, {
            edgeKeys: ['topRight', 'topLeft', 'bottomRight', 'bottomLeft'],
            getEdgePropKey: (edgeKey) => `border-${camelToKebabCase(edgeKey)}-radius`
        });
        this.tryToApplyStyleRule(apply);
    }
    getBorderRadius() {
        return this.rule.getPropOrPropEdges('border-radius', {
            edgeKeys: ['topRight', 'topLeft', 'bottomRight', 'bottomLeft'],
            getEdgePropKey: (edgeKey) => `border-${camelToKebabCase(edgeKey)}-radius`
        });
    }
    setInitialValuesOnChange(changedProp) {
        if (changedProp !== 'width' && this.getWidth() === undefined) {
            this.rule.setProp('border-width', '1px');
        }
        if (changedProp !== 'styleType' && this.getStyleType() === undefined) {
            this.rule.setProp('border-style', 'solid');
        }
        if (changedProp !== 'color' && this.getColor() === undefined) {
            this.rule.setProp('border-color', '#000000');
        }
    }
}
//# sourceMappingURL=border-style.js.map