import { StyleType } from "../models/style.model";
import { isCssPropValueValid } from "../utils";
import { StyleBase } from './style-base';
export class BoxShadowStyle extends StyleBase {
    constructor(element) {
        super();
        this.element = element;
        this.styleType = StyleType.boxShadow;
        this.selector = `${this.styleType}-${this.element.key}`;
        this.styleSheet = this.element.page.getStyleSheet();
    }
    has(effect) {
        const str = this.effectToString(effect);
        return !!this.rule.getProp('box-shadow')?.includes(str);
    }
    set(effect, apply = true) {
        const shadowProp = this.effectToString(effect);
        const boxShadowValue = this.rule.getProp('box-shadow') ?? '';
        const updatedBoxShadowValue = `${boxShadowValue}${boxShadowValue?.length ? ', ' : ''}${shadowProp}`;
        this.rule.setProp('box-shadow', updatedBoxShadowValue);
        this.tryToApplyStyleRule(apply);
    }
    getEffects() {
        return this.rule.getProp('box-shadow')?.split(', ').map((prop) => this.stringToEffect(prop)) || [];
    }
    delete(effect, apply = true) {
        if (!this.rule.getProp('box-shadow')?.length) {
            return;
        }
        const shadowProp = this.effectToString(effect);
        const boxShadowProps = this.rule.getProp('box-shadow').split(', ');
        this.rule.setProp('box-shadow', boxShadowProps.filter((prop) => shadowProp !== prop).join(', '));
        this.tryToApplyStyleRule(apply);
    }
    isValidValue(effect) {
        return isCssPropValueValid('box-shadow', this.effectToString(effect));
    }
    effectToString(shadow) {
        return `${shadow.inner ? 'inset ' : ''}${shadow.x} ${shadow.y} ${shadow.blur} ${shadow.spread} ${shadow.color}`;
    }
    stringToEffect(str) {
        const items = str.split(' ');
        const inner = items[0] === 'inset';
        const [x, y, blur, spread, color] = items.filter(item => item !== 'inset');
        return { inner, x, y, blur, spread, color };
    }
}
//# sourceMappingURL=box-shadow-style.js.map