import { StyleType } from "../models/style.model";
import { StyleBase } from "./style-base";
export class LayoutStyle extends StyleBase {
    constructor(element) {
        super();
        this.element = element;
        this.styleType = StyleType.layout;
        this.selector = `${this.styleType}-${this.element.key}`;
        this.styleSheet = this.element.page.getStyleSheet();
    }
    setPosition({ direction, x, y, gap }, apply = true) {
        this.rule.setProp('display', 'flex');
        this.rule.setProp('flex-direction', direction);
        this.rule.setProp('gap', gap ?? '');
        if (direction === 'row') {
            this.rule.setProp('justify-content', x === 'space-between' || x === 'center' ? x : `flex-${x}`);
            this.rule.setProp('align-items', y === 'center' ? y : `flex-${y}`);
        }
        else if (direction === 'column') {
            this.rule.setProp('justify-content', y === 'center' || y === 'space-between' ? y : `flex-${y}`);
            this.rule.setProp('align-items', x === 'center' ? x : `flex-${x}`);
        }
        this.tryToApplyStyleRule(apply);
    }
    getPosition() {
        if (this.rule.getProp('display') !== 'flex') {
            return undefined;
        }
        const p = {};
        p.direction = this.rule.getProp('flex-direction');
        let xRule, yRule;
        if (p.direction === 'row') {
            xRule = this.rule.getProp('justify-content');
            yRule = this.rule.getProp('align-items');
        }
        else {
            xRule = this.rule.getProp('align-items');
            yRule = this.rule.getProp('justify-content');
        }
        p.x = xRule === 'space-between' || xRule === 'center' ? xRule : xRule.split('-')[1];
        p.y = yRule === 'space-between' || yRule === 'center' ? yRule : yRule.split('-')[1];
        p.gap = this.rule.getProp('gap');
        return p;
    }
    deletePosition(apply = true) {
        this.rule.deleteProp('display');
        this.rule.deleteProp('flex-direction');
        this.rule.deleteProp('justify-content');
        this.rule.deleteProp('align-items');
        this.rule.deleteProp('gap');
        this.tryToApplyStyleRule(apply);
    }
    setPadding(padding, apply = true) {
        this.rule.setPropOrPropEdges('padding', padding);
        this.tryToApplyStyleRule(apply);
    }
    getPadding() {
        return this.rule.getPropOrPropEdges('padding');
    }
    deletePadding(apply = true) {
        this.rule.deleteProp('padding');
        this.rule.deletePropEdges('padding');
        this.tryToApplyStyleRule(apply);
    }
    setMargin(margin, apply = true) {
        this.rule.setPropOrPropEdges('margin', margin);
        this.tryToApplyStyleRule(apply);
    }
    getMargin() {
        return this.rule.getPropOrPropEdges('margin');
    }
    deleteMargin(apply = true) {
        this.rule.deleteProp('margin');
        this.tryToApplyStyleRule(apply);
    }
    setBackgroundColor(color, apply = true) {
        this.rule.setProp('background-color', color);
        this.tryToApplyStyleRule(apply);
    }
    getBackgroundColor() {
        return this.rule.getProp('background-color');
    }
    deleteBackgroundColor(apply = true) {
        this.rule.deleteProp('background-color');
        this.tryToApplyStyleRule(apply);
    }
}
//# sourceMappingURL=layout-style.js.map