import { StyleRule } from "./style-rule";
export class StyleBase {
    constructor() {
        this.rule = new StyleRule();
        this.ruleIndex = -1;
    }
    setStyleRule(ruleValue) {
        this.rule.init(ruleValue);
        this.applyStyleRule();
    }
    applyStyles() {
        this.applyStyleRule();
        this.element.page.schemaChanged();
    }
    tryToApplyStyleRule(apply = true) {
        if (apply) {
            this.applyStyles();
        }
    }
    applyStyleRule() {
        const ruleText = this.rule.generateRuleText();
        if (!ruleText?.length && this.ruleIndex >= 0) {
            this.hardDeleteRule();
            this.updateNodeSchema();
            this.element.emit('view:change');
            return;
        }
        if (ruleText === this.ruleText) {
            return;
        }
        this.ruleText = ruleText;
        if (this.ruleIndex >= 0) {
            this.updateRule();
        }
        else {
            this.insertRule();
        }
        if (!this.element.nativeElement.classList.contains(this.selector)) {
            this.element.nativeElement.classList.add(this.selector);
        }
        this.updateNodeSchema();
        this.element.emit('view:change');
    }
    insertRule() {
        this.ruleIndex = this.styleSheet.insertRule(`.${this.selector}{${this.ruleText}}`, this.ruleIndex >= 0 ? this.ruleIndex : this.styleSheet.cssRules.length);
    }
    updateRule() {
        this.deleteRule();
        this.insertRule();
    }
    deleteRule() {
        this.styleSheet.deleteRule(this.ruleIndex);
    }
    hardDeleteRule() {
        if (!this.styleSheet.cssRules.length) {
            console.warn('No rules were applied, nothing to delete');
            return;
        }
        this.deleteRule();
        this.ruleText = '';
        this.ruleIndex = -1;
    }
    updateNodeSchema() {
        if (!this.ruleText?.length) {
            delete this.element.schema.styles?.[this.styleType];
        }
        else {
            this.element.schema.styles = {
                ...this.element.schema.styles,
                [this.styleType]: this.rule.getAllProps()
            };
        }
    }
}
//# sourceMappingURL=style-base.js.map