export class StyleRule {
    constructor() {
        this.rule = {};
        this.detachedProps = new Set();
    }
    getAllProps() {
        return Object.keys(this.rule).filter(key => !!this.rule[key]).reduce((r, key) => {
            r[key] = this.rule[key];
            return r;
        }, {});
    }
    setProp(key, value) {
        this.rule[key] = value;
    }
    getProp(key) {
        return this.rule[key];
    }
    getPropOrPropEdges(key, options) {
        return this.rule[key] ?? this.getPropEdges(key, options);
    }
    getPropEdges(key, options) {
        const edges = options?.edgeKeys ?? ['left', 'top', 'right', 'bottom'];
        const edgePropKeyFactory = options?.getEdgePropKey ?? ((edgeKey) => `${key}-${edgeKey}`);
        const edgesRule = edges.reduce((r, edge) => {
            const edgePropKey = edgePropKeyFactory(edge);
            if (this.rule[edgePropKey]) {
                r[edge] = this.rule[edgePropKey];
            }
            return r;
        }, {});
        return Object.keys(edgesRule).length ? edgesRule : undefined;
    }
    setPropOrPropEdges(key, value, options) {
        if (typeof value === 'string') {
            this.deletePropEdges(key, options);
            this.rule[key] = value;
            return;
        }
        this.deleteProp(key);
        this.setPropEdges(key, value, options);
    }
    setPropEdges(key, value, options) {
        const edgePropKeyFactory = options?.getEdgePropKey ?? ((edgeKey) => `${key}-${edgeKey}`);
        Object.entries(value).forEach(([edgeKey, value]) => {
            const edgePropKey = edgePropKeyFactory(edgeKey);
            this.rule[edgePropKey] = value;
        });
    }
    attachProp(key) {
        this.detachedProps.delete(key);
    }
    detachProp(key) {
        this.detachedProps.add(key);
    }
    detached(key) {
        return this.detachedProps.has(key);
    }
    init(rule) {
        this.rule = rule;
    }
    deleteProp(key) {
        delete this.rule[key];
    }
    deletePropEdges(key, options) {
        const edges = options?.edgeKeys ?? ['left', 'top', 'right', 'bottom'];
        const edgePropKeyFactory = options?.getEdgePropKey ?? ((edgeKey) => `${key}-${edgeKey}`);
        edges.forEach(edgeKey => {
            const edgePropKey = edgePropKeyFactory(edgeKey);
            delete this.rule[edgePropKey];
        });
    }
    entries() {
        return Object.entries(this.rule);
    }
    generateRuleText() {
        return this.entries()
            .filter(([key, value]) => !this.detachedProps.has(key) && !!value)
            .reduce((result, [key, value]) => {
            const ruleText = `${key}: ${value};`;
            result += ruleText;
            return result;
        }, '');
    }
}
//# sourceMappingURL=style-rule.js.map