// ChatGPT
export function parseHTMLFragment(fragment) {
    // Create a new DOMParser
    const parser = new DOMParser();
    // Parse the HTML string into a DOM document
    const doc = parser.parseFromString(fragment, 'text/html');
    // Recursive function to parse DOM elements
    function parseElement(element) {
        const obj = {
            tag: element.tagName.toLowerCase(),
            attributes: [],
            children: [],
            cssClasses: element.classList.value.split(' ')
        };
        // Parse attributes
        for (const attr of element.attributes) {
            if (attr.name !== 'class') {
                obj.attributes.push({ name: attr.name, value: attr.value });
            }
        }
        // Parse child nodes (both elements and text nodes)
        for (const child of element.childNodes) {
            if (child.nodeType === Node.ELEMENT_NODE) {
                obj.children.push(parseElement(child)); // Recursive call for elements
            }
            else if (child.nodeType === Node.TEXT_NODE && child.textContent.trim()) {
                obj.children.push({
                    tag: "#text",
                    attributes: [{ name: 'text', value: child.textContent.trim() }]
                });
            }
        }
        return obj;
    }
    // Start parsing from the body of the document
    const result = [];
    for (const child of Array.from(doc.body.children)) {
        result.push(parseElement(child));
    }
    return result;
}
export function kebabToCamelCase(str) {
    return str.replace(/-([a-z])/g, function (match, letter) {
        return letter.toUpperCase();
    });
}
export function camelToKebabCase(str) {
    return str.replace(/([A-Z])/g, '-$1').toLowerCase();
}
export function hexToRgb(hex) {
    // Remove the '#' if it's included in the hex value
    hex = hex.replace(/^#/, '');
    // If the hex is shorthand (e.g. #03F), expand it to full form (e.g. #0033FF)
    if (hex.length === 3) {
        hex = hex.split('').map(char => char + char).join('');
    }
    // Parse the r, g, b values from the hex string
    const bigint = parseInt(hex, 16);
    const r = (bigint >> 16) & 255;
    const g = (bigint >> 8) & 255;
    const b = bigint & 255;
    return `rgb(${r}, ${g}, ${b})`;
}
function isHexColor(str) {
    // Regular expression to match valid hex color codes (#RRGGBB or #RGB)
    const hexRegex = /^#([A-Fa-f0-9]{3}){1,2}$/;
    return hexRegex.test(str);
}
export function isCssPropNameValid(element, propertyName) {
    const propToCheck = kebabToCamelCase(propertyName);
    const hasProp = element.style.hasOwnProperty(propToCheck);
    return hasProp;
}
;
export function isCssPropValueValid(propertyName, propertyValue) {
    const propToCheck = camelToKebabCase(propertyName);
    const propValueToCheck = propertyValue.split(' ').map(item => isHexColor(item) ? hexToRgb(item) : item).join(' ');
    if (CSS.supports(propToCheck, propValueToCheck)) {
        return true;
    }
    // Optionally check for vendor prefixes
    const prefixes = ['-webkit-', '-moz-', '-ms-', '-o-'];
    return prefixes.some(prefix => CSS.supports(prefix + propToCheck, propertyValue));
}
//# sourceMappingURL=utils.js.map